@@ -4,6 +4,7 @@ from fief.db import AsyncSession, get_global_async_session
 from fief.managers import (
     AccountManager,
     AccountUserManager,
+    AdminAPIKeyManager,
     AdminSessionTokenManager,
     get_manager,
 )
@@ -21,6 +22,12 @@ async def get_admin_session_token_manager(
     return get_manager(AdminSessionTokenManager, session)
 
 
+async def get_admin_api_key_manager(
+    session: AsyncSession = Depends(get_global_async_session),
+) -> AdminAPIKeyManager:
+    return get_manager(AdminAPIKeyManager, session)
+
+
 async def get_account_user_manager(
     session: AsyncSession = Depends(get_global_async_session),
 ) -> AccountUserManager:
