@@ -3,6 +3,7 @@ from typing import List, Optional, Tuple
 from fastapi import Depends, HTTPException, Query, status
 from sqlalchemy import select
 
+from fief import schemas
 from fief.dependencies.account_managers import get_tenant_manager
 from fief.dependencies.pagination import (
     Ordering,
@@ -11,6 +12,7 @@ from fief.dependencies.pagination import (
     get_paginated_objects,
     get_pagination,
 )
+from fief.errors import APIErrorCode
 from fief.managers import TenantManager
 from fief.models import Tenant
 
@@ -30,10 +32,30 @@ async def get_current_tenant(
     return tenant
 
 
+async def get_tenant_from_create_user_internal(
+    user_create: schemas.user.UserCreateInternal,
+    manager: TenantManager = Depends(get_tenant_manager),
+) -> Tenant:
+    tenant = await manager.get_by_id(user_create.tenant_id)
+
+    if tenant is None:
+        raise HTTPException(
+            status_code=status.HTTP_400_BAD_REQUEST,
+            detail=APIErrorCode.USER_CREATE_UNKNOWN_TENANT,
+        )
+
+    return tenant
+
+
 async def get_paginated_tenants(
+    query: Optional[str] = Query(None),
     pagination: Pagination = Depends(get_pagination),
     ordering: Ordering = Depends(get_ordering),
     manager: TenantManager = Depends(get_tenant_manager),
 ) -> Tuple[List[Tenant], int]:
     statement = select(Tenant)
+
+    if query is not None:
+        statement = statement.where(Tenant.name.ilike(f"%{query}%"))
+
     return await get_paginated_objects(statement, pagination, ordering, manager)
