@@ -37,18 +37,22 @@ from fief.dependencies.pagination import (
     get_pagination,
 )
 from fief.dependencies.tasks import get_send_task
-from fief.dependencies.tenant import get_current_tenant
+from fief.dependencies.tenant import (
+    get_current_tenant,
+    get_tenant_from_create_user_internal,
+)
 from fief.locale import Translations
 from fief.managers import UserManager as UserDBManager
 from fief.models import Account, Tenant, User
-from fief.schemas.user import UserCreate, UserCreateInternal, UserDB
+from fief.schemas.user import UserCreate, UserDB
+from fief.settings import settings
 from fief.tasks import SendTask, on_after_forgot_password, on_after_register
 
 
 class UserManager(BaseUserManager[UserCreate, UserDB]):
     user_db_model = UserDB
-    reset_password_token_secret = "SECRET"
-    verification_token_secret = "SECRET"
+    reset_password_token_secret = settings.secret.get_secret_value()
+    verification_token_secret = settings.secret.get_secret_value()
 
     def __init__(
         self,
@@ -74,15 +78,6 @@ class UserManager(BaseUserManager[UserCreate, UserDB]):
                 )
             )
 
-    async def create(
-        self, user: UserCreate, safe: bool = False, request: Optional[Request] = None
-    ) -> UserDB:
-        user_dict = (
-            user.create_update_dict() if safe else user.create_update_dict_superuser()
-        )
-        user_create = UserCreateInternal(**user_dict, tenant_id=self.tenant.id)
-        return await super().create(user_create, safe=safe, request=request)
-
     async def on_after_register(self, user: UserDB, request: Optional[Request] = None):
         self.send_task(on_after_register, str(user.id), str(self.account.id))
 
@@ -167,6 +162,25 @@ async def get_user_manager(
     return UserManager(user_db, account, tenant, translations, send_task)
 
 
+async def get_user_db_from_create_user_internal(
+    session: AsyncSession = Depends(get_current_account_session),
+    tenant: Tenant = Depends(get_tenant_from_create_user_internal),
+) -> SQLAlchemyUserDatabase[UserDB]:
+    return SQLAlchemyUserTenantDatabase(UserDB, session, tenant, User)
+
+
+async def get_user_manager_from_create_user_internal(
+    user_db: SQLAlchemyUserDatabase[UserDB] = Depends(
+        get_user_db_from_create_user_internal
+    ),
+    tenant: Tenant = Depends(get_tenant_from_create_user_internal),
+    account: Account = Depends(get_current_account),
+    translations: Translations = Depends(get_translations),
+    send_task: SendTask = Depends(get_send_task),
+):
+    return UserManager(user_db, account, tenant, translations, send_task)
+
+
 class AuthorizationCodeBearerTransport(BearerTransport):
     scheme: OAuth2AuthorizationCodeBearer  # type: ignore
 
